@@ -19,6 +19,45 @@ package org.apache.maven.plugin.javadoc;
  * under the License.
  */
 
+import org.apache.commons.lang.SystemUtils;
+import org.apache.http.HttpHost;
+import org.apache.http.HttpResponse;
+import org.apache.http.HttpStatus;
+import org.apache.http.auth.AuthScope;
+import org.apache.http.auth.Credentials;
+import org.apache.http.auth.UsernamePasswordCredentials;
+import org.apache.http.client.HttpClient;
+import org.apache.http.client.methods.HttpGet;
+import org.apache.http.client.params.ClientPNames;
+import org.apache.http.conn.params.ConnRoutePNames;
+import org.apache.http.impl.client.DefaultHttpClient;
+import org.apache.http.impl.conn.PoolingClientConnectionManager;
+import org.apache.http.params.CoreConnectionPNames;
+import org.apache.http.params.CoreProtocolPNames;
+import org.apache.maven.artifact.Artifact;
+import org.apache.maven.plugin.logging.Log;
+import org.apache.maven.project.MavenProject;
+import org.apache.maven.settings.Proxy;
+import org.apache.maven.settings.Settings;
+import org.apache.maven.shared.invoker.DefaultInvocationRequest;
+import org.apache.maven.shared.invoker.DefaultInvoker;
+import org.apache.maven.shared.invoker.InvocationOutputHandler;
+import org.apache.maven.shared.invoker.InvocationRequest;
+import org.apache.maven.shared.invoker.InvocationResult;
+import org.apache.maven.shared.invoker.Invoker;
+import org.apache.maven.shared.invoker.MavenInvocationException;
+import org.apache.maven.shared.invoker.PrintStreamHandler;
+import org.apache.maven.wagon.proxy.ProxyInfo;
+import org.apache.maven.wagon.proxy.ProxyUtils;
+import org.codehaus.plexus.util.DirectoryScanner;
+import org.codehaus.plexus.util.FileUtils;
+import org.codehaus.plexus.util.IOUtil;
+import org.codehaus.plexus.util.Os;
+import org.codehaus.plexus.util.StringUtils;
+import org.codehaus.plexus.util.cli.CommandLineException;
+import org.codehaus.plexus.util.cli.CommandLineUtils;
+import org.codehaus.plexus.util.cli.Commandline;
+
 import java.io.BufferedReader;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -39,6 +78,7 @@ import java.net.URLClassLoader;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.List;
 import java.util.Locale;
 import java.util.NoSuchElementException;
@@ -51,44 +91,11 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
-import org.apache.commons.httpclient.Credentials;
-import org.apache.commons.httpclient.HttpClient;
-import org.apache.commons.httpclient.HttpStatus;
-import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
-import org.apache.commons.httpclient.UsernamePasswordCredentials;
-import org.apache.commons.httpclient.auth.AuthScope;
-import org.apache.commons.httpclient.methods.GetMethod;
-import org.apache.commons.httpclient.params.HttpClientParams;
-import org.apache.commons.httpclient.params.HttpMethodParams;
-import org.apache.commons.lang.SystemUtils;
-import org.apache.maven.artifact.Artifact;
-import org.apache.maven.plugin.logging.Log;
-import org.apache.maven.project.MavenProject;
-import org.apache.maven.settings.Proxy;
-import org.apache.maven.settings.Settings;
-import org.apache.maven.shared.invoker.DefaultInvocationRequest;
-import org.apache.maven.shared.invoker.DefaultInvoker;
-import org.apache.maven.shared.invoker.InvocationOutputHandler;
-import org.apache.maven.shared.invoker.InvocationRequest;
-import org.apache.maven.shared.invoker.InvocationResult;
-import org.apache.maven.shared.invoker.Invoker;
-import org.apache.maven.shared.invoker.MavenInvocationException;
-import org.apache.maven.shared.invoker.PrintStreamHandler;
-import org.apache.maven.wagon.proxy.ProxyInfo;
-import org.apache.maven.wagon.proxy.ProxyUtils;
-import org.codehaus.plexus.util.FileUtils;
-import org.codehaus.plexus.util.IOUtil;
-import org.codehaus.plexus.util.Os;
-import org.codehaus.plexus.util.StringUtils;
-import org.codehaus.plexus.util.cli.CommandLineException;
-import org.codehaus.plexus.util.cli.CommandLineUtils;
-import org.codehaus.plexus.util.cli.Commandline;
-
 /**
  * Set of utilities methods for Javadoc.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: JavadocUtil.java 1098139 2011-04-30 18:59:02Z hboutemy $
+ * @version $Id: JavadocUtil.java 1463966 2013-04-03 12:40:40Z olamy $
  * @since 2.4
  */
 public class JavadocUtil
@@ -98,8 +105,8 @@ public class JavadocUtil
 
     /** Error message when VM could not be started using invoker. */
     protected static final String ERROR_INIT_VM =
-        "Error occurred during initialization of VM, try to reduce the Java heap size for the MAVEN_OPTS " +
-        "environnement variable using -Xms:<size> and -Xmx:<size>.";
+        "Error occurred during initialization of VM, try to reduce the Java heap size for the MAVEN_OPTS "
+        + "environnement variable using -Xms:<size> and -Xmx:<size>.";
 
     /**
      * Method that removes the invalid directories in the specified directories.
@@ -396,7 +403,7 @@ public class JavadocUtil
      * @param sourceDirectory the directory where the source files are located
      * @param fileList        the list of all files found in the sourceDirectory
      * @param excludePackages package names to be excluded in the javadoc
-     * @return a StringBuffer that contains the appended file names of the files to be included in the javadoc
+     * @return a StringBuilder that contains the appended file names of the files to be included in the javadoc
      */
     protected static List<String> getIncludedFiles( File sourceDirectory, String[] fileList, String[] excludePackages )
     {
@@ -500,7 +507,7 @@ public class JavadocUtil
             int idx = file.lastIndexOf( File.separatorChar );
             String tmpStr = file.substring( 0, idx );
             tmpStr = tmpStr.replace( '\\', '/' );
-            String[] srcSplit = tmpStr.split( sourceDirectory.replace( '\\', '/' ) + '/' );
+            String[] srcSplit = tmpStr.split( Pattern.quote( sourceDirectory.replace( '\\', '/' ) + '/' ) );
             String excludedPackage = srcSplit[1].replace( '/', '.' );
 
             if ( !excluded.contains( excludedPackage ) )
@@ -519,12 +526,35 @@ public class JavadocUtil
      * @param files the variable that contains the appended filenames of the files to be included in the javadoc
      * @param excludePackages the packages to be excluded in the javadocs
      */
-    protected static void addFilesFromSource( List<String> files, File sourceDirectory, String[] excludePackages )
+    protected static void addFilesFromSource( List<String> files, File sourceDirectory,
+                                              List<String> sourceFileIncludes,
+                                              List<String> sourceFileExcludes,
+                                              String[] excludePackages )
     {
-        String[] fileList = FileUtils.getFilesFromExtension( sourceDirectory.getPath(), new String[] { "java" } );
-        if ( fileList != null && fileList.length != 0 )
+        DirectoryScanner ds = new DirectoryScanner();
+        if ( sourceFileIncludes == null )
         {
-            List<String> tmpFiles = getIncludedFiles( sourceDirectory, fileList, excludePackages );
+            sourceFileIncludes = Collections.singletonList( "**/*.java" );
+        }
+        ds.setIncludes( sourceFileIncludes.toArray( new String[sourceFileIncludes.size()] ) );
+        if ( sourceFileExcludes != null && sourceFileExcludes.size() > 0 )
+        {
+            ds.setExcludes( sourceFileExcludes.toArray( new String[sourceFileExcludes.size()] ) );
+        }
+        ds.setBasedir( sourceDirectory );
+        ds.scan();
+
+        String[] fileList = ds.getIncludedFiles();
+        String[] pathList = new String[fileList.length];
+        for ( int x = 0; x < fileList.length; x++ )
+        {
+            pathList[x] = new File( sourceDirectory, fileList[x] ).getAbsolutePath( );
+        }
+
+
+        if (  pathList.length != 0 )
+        {
+            List<String> tmpFiles = getIncludedFiles( sourceDirectory, pathList, excludePackages );
             files.addAll( tmpFiles );
         }
     }
@@ -563,7 +593,7 @@ public class JavadocUtil
 
         if ( exitCode != 0 )
         {
-            StringBuffer msg = new StringBuffer( "Exit code: " + exitCode + " - " + err.getOutput() );
+            StringBuilder msg = new StringBuilder( "Exit code: " + exitCode + " - " + err.getOutput() );
             msg.append( '\n' );
             msg.append( "Command line was:" + CommandLineUtils.toString( cmd.getCommandline() ) );
             throw new CommandLineException( msg.toString() );
@@ -871,7 +901,7 @@ public class JavadocUtil
             file.getParentFile().mkdirs();
         }
 
-        FileOutputStream os = null;
+        OutputStream os = null;
         try
         {
             os = new FileOutputStream( file );
@@ -1026,7 +1056,7 @@ public class JavadocUtil
         {
             return FileUtils.fileRead( javaFile, encoding );
         }
-        catch (IOException e )
+        catch ( IOException e )
         {
             return null;
         }
@@ -1658,7 +1688,8 @@ public class JavadocUtil
         }
 
         BufferedReader reader = null;
-        GetMethod httpMethod = null;
+        HttpGet httpMethod = null;
+        HttpClient httpClient = null;
 
         try
         {
@@ -1670,29 +1701,29 @@ public class JavadocUtil
             else
             {
                 // http, https...
-                HttpClient httpClient = createHttpClient( settings, url );
+                httpClient = createHttpClient( settings, url );
 
-                httpMethod = new GetMethod( url.toString() );
-                int status;
+                httpMethod = new HttpGet( url.toString() );
+                HttpResponse response;
                 try
                 {
-                    status = httpClient.executeMethod( httpMethod );
+                    response = httpClient.execute( httpMethod );
                 }
                 catch ( SocketTimeoutException e )
                 {
                     // could be a sporadic failure, one more retry before we give up
-                    status = httpClient.executeMethod( httpMethod );
+                    response = httpClient.execute( httpMethod );
                 }
 
+                int status = response.getStatusLine().getStatusCode();
                 if ( status != HttpStatus.SC_OK )
                 {
                     throw new FileNotFoundException(
                         "Unexpected HTTP status code " + status + " getting resource " + url.toExternalForm() + "." );
-
                 }
 
                 // Intentionally using the platform default encoding here since this is what Javadoc uses internally.
-                reader = new BufferedReader( new InputStreamReader( httpMethod.getResponseBodyAsStream() ) );
+                reader = new BufferedReader( new InputStreamReader( response.getEntity().getContent() ) );
             }
 
             if ( validateContent )
@@ -1717,6 +1748,10 @@ public class JavadocUtil
             {
                 httpMethod.releaseConnection();
             }
+            if ( httpClient != null )
+            {
+                httpClient.getConnectionManager().shutdown();
+            }
         }
     }
 
@@ -1724,7 +1759,8 @@ public class JavadocUtil
     {
         if ( StringUtils.isEmpty( str ) )
         {
-            return false;
+            // unnamed package is valid (even if bad practice :) )
+            return true;
         }
 
         int idx;
@@ -1772,13 +1808,13 @@ public class JavadocUtil
      */
     private static HttpClient createHttpClient( Settings settings, URL url )
     {
-        HttpClient httpClient = new HttpClient( new MultiThreadedHttpConnectionManager() );
-        httpClient.getHttpConnectionManager().getParams().setConnectionTimeout( DEFAULT_TIMEOUT );
-        httpClient.getHttpConnectionManager().getParams().setSoTimeout( DEFAULT_TIMEOUT );
-        httpClient.getParams().setBooleanParameter( HttpClientParams.ALLOW_CIRCULAR_REDIRECTS, true );
+        DefaultHttpClient httpClient = new DefaultHttpClient( new PoolingClientConnectionManager() );
+        httpClient.getParams().setIntParameter( CoreConnectionPNames.SO_TIMEOUT, DEFAULT_TIMEOUT );
+        httpClient.getParams().setIntParameter( CoreConnectionPNames.CONNECTION_TIMEOUT, DEFAULT_TIMEOUT );
+        httpClient.getParams().setBooleanParameter( ClientPNames.ALLOW_CIRCULAR_REDIRECTS, true );
 
         // Some web servers don't allow the default user-agent sent by httpClient
-        httpClient.getParams().setParameter( HttpMethodParams.USER_AGENT,
+        httpClient.getParams().setParameter( CoreProtocolPNames.USER_AGENT,
                                              "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)" );
 
         if ( settings != null && settings.getActiveProxy() != null )
@@ -1791,14 +1827,15 @@ public class JavadocUtil
             if ( StringUtils.isNotEmpty( activeProxy.getHost() )
                  && ( url == null || !ProxyUtils.validateNonProxyHosts( proxyInfo, url.getHost() ) ) )
             {
-                httpClient.getHostConfiguration().setProxy( activeProxy.getHost(), activeProxy.getPort() );
+                HttpHost proxy = new HttpHost(activeProxy.getHost(), activeProxy.getPort());
+                httpClient.getParams().setParameter(ConnRoutePNames.DEFAULT_PROXY, proxy);
 
                 if ( StringUtils.isNotEmpty( activeProxy.getUsername() ) && activeProxy.getPassword() != null )
                 {
                     Credentials credentials =
                         new UsernamePasswordCredentials( activeProxy.getUsername(), activeProxy.getPassword() );
 
-                    httpClient.getState().setProxyCredentials( AuthScope.ANY, credentials );
+                    httpClient.getCredentialsProvider().setCredentials(AuthScope.ANY, credentials);
                 }
             }
         }
